Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(931)

Unified Diff: chrome/browser/chromeos/profiles/profile_helper.cc

Issue 2827523003: Move BrowsingDataRemover to content/ (Closed)
Patch Set: Rebase over codereview.chromium.org/2815913005 Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/profiles/profile_helper.cc
diff --git a/chrome/browser/chromeos/profiles/profile_helper.cc b/chrome/browser/chromeos/profiles/profile_helper.cc
index a319f9b7add50b1462b34c30e536113acea02252..ce167e6e44e1025084ea0e8be232c59052a2f962 100644
--- a/chrome/browser/chromeos/profiles/profile_helper.cc
+++ b/chrome/browser/chromeos/profiles/profile_helper.cc
@@ -10,8 +10,7 @@
#include "base/strings/string_util.h"
#include "chrome/browser/browser_process.h"
#include "chrome/browser/browsing_data/browsing_data_helper.h"
-#include "chrome/browser/browsing_data/browsing_data_remover.h"
-#include "chrome/browser/browsing_data/browsing_data_remover_factory.h"
+
#include "chrome/browser/browsing_data/chrome_browsing_data_remover_delegate.h"
#include "chrome/browser/chromeos/base/file_flusher.h"
#include "chrome/browser/chromeos/login/helper.h"
@@ -30,6 +29,7 @@
#include "components/user_manager/user.h"
#include "components/user_manager/user_manager.h"
#include "content/public/browser/browser_thread.h"
+#include "content/public/browser/browsing_data_remover.h"
#include "content/public/browser/storage_partition.h"
#include "content/public/browser/web_contents.h"
#include "extensions/browser/guest_view/web_view/web_view_guest.h"
@@ -261,7 +261,7 @@ void ProfileHelper::ClearSigninProfile(const base::Closure& on_clear_callback) {
if (profile_manager->GetProfileByPath(GetSigninProfileDir())) {
LOG_ASSERT(!browsing_data_remover_);
browsing_data_remover_ =
- BrowsingDataRemoverFactory::GetForBrowserContext(GetSigninProfile());
+ content::BrowserContext::GetBrowsingDataRemover(GetSigninProfile());
browsing_data_remover_->AddObserver(this);
browsing_data_remover_->RemoveAndReply(
base::Time(), base::Time::Max(),
@@ -403,7 +403,7 @@ void ProfileHelper::OnSigninProfileCleared() {
}
////////////////////////////////////////////////////////////////////////////////
// ProfileHelper, BrowsingDataRemover::Observer implementation:
void ProfileHelper::OnBrowsingDataRemoverDone() {
LOG_ASSERT(browsing_data_remover_);
« no previous file with comments | « chrome/browser/chromeos/profiles/profile_helper.h ('k') | chrome/browser/extensions/api/browsing_data/browsing_data_api.h » ('j') | no next file with comments »
@@ -403,7 +403,7 @@ void ProfileHelper::OnSigninProfileCleared() {
}
////////////////////////////////////////////////////////////////////////////////
-// ProfileHelper, BrowsingDataRemover::Observer implementation:
+// ProfileHelper, content::BrowsingDataRemover::Observer implementation:
void ProfileHelper::OnBrowsingDataRemoverDone() {
LOG_ASSERT(browsing_data_remover_);

Powered by Google App Engine
This is Rietveld 408576698